@@ -14,7 +14,7 @@
 ** other files are for internal use by SQLite and should not be
 ** accessed by users of the library.
 **
-** $Id: main.c,v 1.133 2003/06/02 18:17:33 drh Exp $
+** $Id: main.c,v 1.140 2003/07/27 17:26:23 drh Exp $
 */
 #include "sqliteInt.h"
 #include "os.h"
@@ -58,6 +58,7 @@ int sqliteInitCallback(void *pInit, int argc, char **argv, char **azColName){
   int nErr = 0;
 
   assert( argc==5 );
+  if( argv==0 ) return 0;   /* Might happen if EMPTY_RESULT_CALLBACKS are on */
   if( argv[0]==0 ){
     corruptSchema(pData);
     return 1;
@@ -440,6 +441,9 @@ sqlite *sqlite_open(const char *zFilename, int mode, char **pzErrMsg){
   }
   
   /* Open the backend database driver */
+  if( zFilename[0]==':' && strcmp(zFilename,":memory:")==0 ){
+    db->temp_store = 2;
+  }
   rc = sqliteBtreeFactory(db, zFilename, 0, MAX_PAGES, &db->aDb[0].pBt);
   if( rc!=SQLITE_OK ){
     switch( rc ){
@@ -642,7 +646,7 @@ static int sqliteMain(
   if( sParse.useCallback==0 ){
     assert( ppVm );
     *ppVm = (sqlite_vm*)sParse.pVdbe;
-    *pzTail = sParse.zTail;
+    if( pzTail ) *pzTail = sParse.zTail;
   }
   if( sqliteSafetyOff(db) ) goto exec_misuse;
   return sParse.rc;
@@ -711,6 +715,21 @@ int sqlite_finalize(
   return rc;
 }
 
+/*
+** Destroy a virtual machine in the same manner as sqlite_finalize(). If 
+** possible, leave *ppVm pointing at a new virtual machine which may be
+** used to re-execute the query.
+*/
+int sqlite_reset(
+  sqlite_vm *pVm,            /* The virtual machine to be destroyed */
+  char **pzErrMsg,           /* OUT: Write error messages here */
+  sqlite_vm **ppVm           /* OUT: The new virtual machine */
+){
+  int rc = sqliteVdbeReset((Vdbe*)pVm, pzErrMsg, (Vdbe **)ppVm);
+  sqliteStrRealloc(pzErrMsg);
+  return rc;
+}
+
 /*
 ** Return a static string that describes the kind of error specified in the
 ** argument.
@@ -742,6 +761,7 @@ const char *sqlite_error_string(int rc){
     case SQLITE_MISUSE:     z = "library routine called out of sequence";break;
     case SQLITE_NOLFS:      z = "kernel lacks large file support";       break;
     case SQLITE_AUTH:       z = "authorization denied";                  break;
+    case SQLITE_FORMAT:     z = "auxiliary database format error";       break;
     default:                z = "unknown error";                         break;
   }
   return z;
